=======================
fast-templates
=======================

CLI that contains fastapi templates for different projects

Installation
============

Use the package manager `pip <https://pip.pypa.io/en/stable/>`_ to install Fast-Templates.

.. code-block:: bash

   pip install fast-templates

Usage
=====

.. code-block:: bash

   fastcli

License
=======

`Mozilla Public License Version 2.0 <https://www.mozilla.org/en-US/MPL/2.0/>`_